@@ -8,7 +8,7 @@ from app.models.user.members import Members
 
 
 @admin.register(Members)
-class MembersAdmin(admin.ModelAdmin):
+class SeatUserAdmin(admin.ModelAdmin):
     list_display = (
         'id', 'username', 'name', 'is_staff', 'is_active', 'email', 'access_key', 'secret_key', 'ctime', 'mtime'
     )
