@@ -7,6 +7,7 @@ from rest_framework.throttling import ScopedRateThrottle
 
 
 class CustomBaseThrottle(ScopedRateThrottle):
+    """自定义请求限流基类"""
 
     def get_cache_key(self, request, view):
         """
@@ -24,3 +25,19 @@ class CustomBaseThrottle(ScopedRateThrottle):
             'scope': self.scope,
             'ident': ident
         }
+
+
+class CustomAnonRateThrottle(ScopedRateThrottle):
+    """
+    自定义匿名用户请求限流
+    """
+
+    def get_cache_key(self, request, view):
+
+        if request.user.is_authenticated:
+            return None  # Only throttle unauthenticated requests.
+
+        return self.cache_format % {
+            'scope': self.scope,
+            'ident': self.get_ident(request)
+        }
\ No newline at end of file
